summaryrefslogtreecommitdiffstats
path: root/arch/m68k/atari
diff options
context:
space:
mode:
authorRalf Baechle <ralf@linux-mips.org>2001-01-11 04:02:40 +0000
committerRalf Baechle <ralf@linux-mips.org>2001-01-11 04:02:40 +0000
commite47f00743fc4776491344f2c618cc8dc2c23bcbc (patch)
tree13e03a113a82a184c51c19c209867cfd3a59b3b9 /arch/m68k/atari
parentb2ad5f821b1381492d792ca10b1eb7a107b48f14 (diff)
Merge with Linux 2.4.0.
Diffstat (limited to 'arch/m68k/atari')
-rw-r--r--arch/m68k/atari/debug.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/m68k/atari/debug.c b/arch/m68k/atari/debug.c
index 2900f7758..75c9c4471 100644
--- a/arch/m68k/atari/debug.c
+++ b/arch/m68k/atari/debug.c
@@ -94,7 +94,7 @@ static int ata_par_out (char c)
{
unsigned char tmp;
/* This a some-seconds timeout in case no printer is connected */
- unsigned long i = loops_per_sec > 1 ? loops_per_sec : 10000000;
+ unsigned long i = loops_per_jiffy > 1 ? loops_per_jiffy : 10000000/HZ;
while( (mfp.par_dt_reg & 1) && --i ) /* wait for BUSY == L */
;
@@ -196,7 +196,7 @@ void atari_init_mfp_port( int cflag )
MFPDELAY(); \
} while(0)
/* loops_per_sec isn't initialized yet, so we can't use udelay(). This does a
* delay of ~ 60us. */
#define LONG_DELAY() \
do { \
@@ -196,7 +196,7 @@ void atari_init_mfp_port( int cflag )
MFPDELAY(); \
} while(0)
-/* loops_per_sec isn't initialized yet, so we can't use udelay(). This does a
+/* loops_per_jiffy isn't initialized yet, so we can't use udelay(). This does a
* delay of ~ 60us. */
#define LONG_DELAY() \